<?php
session_start();

// Check if the user is not logged in, redirect to login page
if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
    header('Location: login.php');
    exit;
}

// Database connection details
$dbHost = 'localhost';
$dbName = 'cocoeatz_app';
$dbUser = 'cocoeatz_test';
$dbPassword = 'Msnt@786';

try {
    // Connect to Database
    $db = new PDO("mysql:host=$dbHost;dbname=$dbName", $dbUser, $dbPassword);
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

$today = date('Y-m-d');
$yesterday = date('Y-m-d', strtotime('-1 day'));

// Fetch non take_away orders where restaurant_id is 3, 4, or 5, order_status is not 'delivered' or 'canceled', created_at is today, and payment_method is not 'digital_payment'
$query = $db->prepare("SELECT id, order_status, payment_status, created_at, restaurant_id, delivery_man_id, order_note FROM orders WHERE restaurant_id =2 AND order_status NOT IN ('delivered', 'canceled') AND DATE(created_at) = :today AND payment_method != 'digital_payment' AND order_type != 'take_away' ORDER BY created_at DESC");
$query->bindParam(':today', $today);
$query->execute();
$nonTakeAwayOrders = $query->fetchAll(PDO::FETCH_ASSOC);

// Fetch take_away orders where restaurant_id is 3, 4, or 5, order_status is not 'delivered' or 'canceled', created_at is today, and payment_method is not 'digital_payment'
$query = $db->prepare("SELECT id, order_status, payment_status, created_at, restaurant_id, delivery_man_id, order_note FROM orders WHERE restaurant_id =2 AND order_status NOT IN ('delivered', 'canceled') AND DATE(created_at) = :today AND payment_method != 'digital_payment' AND order_type = 'take_away' ORDER BY created_at DESC");
$query->bindParam(':today', $today);
$query->execute();
$takeAwayOrders = $query->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Order Management System</title>
    <style>
        body {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-content: flex-start;
            padding: 10px;
            font-family: Arial, sans-serif;
        }

        .order-box {
            padding: 20px;
            background-color: #f0f0f0;
            border-radius: 5px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            flex-basis: calc(5/7 * 25% - 20px);
            position: relative;
            overflow: hidden;
        }

        .order-box.processing {
            background-color: #FFFF6E; /* Yellow background for assigned orders */
        }

        .order-box.handover {
            background-color: #ADD8E6; /* Blue background for handover orders */
        }

        .order-box.picked_up {
            background-color: #f0fff0; /* Light green */
        }


        .order-box.take-away {
            background-color: #ffdab9; /* Light pink background for take_away orders */
        }

        .order-box.take-away.processing {
            background-color: #FFBF00; /* Dark blue background for processing take_away orders */
        }

        .order-box:not(.processing):not(.take-away):hover {
            background-color: #e6e6e6;
            cursor: pointer;
        }
          .order-header {
            width: 100%;
            background-color: #ff8c00;
            color: white;
            text-align: center;
            padding: 5px;
            position: absolute;
            top: 0;
            left: 0;
        }

        .order-header img {
            max-width: 50%;
            height: auto;
            float: left;
           margin-left: 15px;
        }
        .order-box.take-away:hover {
            background-color: #ffc0cb; /* Light pink background for take_away orders on hover */
        }

        .order-box.take-away.processing:hover {
            background-color: #8a2be2; /* Dark blue background for processing take_away orders on hover */
        }

        .order-box .restaurant-name {
            font-weight: bold;
            margin-top: 10px;
        }

        .order-box strong {
            font-size: 18px;
        }

        .order-box .time {
            font-size: 14px;
            color: #666;
        }

        .order-box .status {
            position: absolute;
            top: 7px;
            right: 10px;
            padding: 7px;
            border-radius: 5px;
            font-size: 10px;
            color: white;
        }

        .order-box .status.paid {
            background-color: green;
        }

        .order-box .status.unpaid {
            background-color: red;
        }
        .order-box .restaurant-name {
    font-style: italic;
    font-weight: Normal;
    font-size: 10px;
            margin-top: 25px; /* Adjust the margin-top value as needed */
}

        .order-box .driver-box .driver-name {
            display: inline-block;
            padding: 5px 10px;
            background-color: orange;
            border-radius: 5px;
            color: white;
            font-weight: bold;
        }

        .order-box .delivery-instruction,
        .order-box .unavailable-item-note,
        .order-box .order-note {
            margin-top: 10px;
            font-size: 12px;
        }

        .order-box .delivery-instruction p,
        .order-box .unavailable-item-note p,
        .order-box .order-note p {
            font-style: italic;
            margin-top: 5px;
        }
        
  .item-box {
    padding: 10px;
    background-color: #fff;
    border-radius: 5px;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    margin-top: 3px;
    cursor: pointer;
    width: 100%; /* Stretch item box to full width */
    box-sizing: border-box; /* Ensure padding is included in the width */
}
.item-details {
    font-weight: bold;
    text-transform: uppercase; /* Convert text to uppercase */
}

.variation {
    font-size: 12px; /* Reduce variation size */
    margin-top: 0px; /* Add space between variations */
}

    </style>
</head>
<body>
<!-- Display non take_away orders -->
<?php foreach ($nonTakeAwayOrders as $order) : ?>
    <?php
        // Convert created_at to DateTime object
        $createdAt = new DateTime($order['created_at']);
        // Format date and time
        $formattedDateTime = $createdAt->format('Y-m-d H:i:s');
        // Determine the class for the payment status box
        $paymentStatusClass = ($order['payment_status'] === 'paid') ? 'paid' : 'unpaid';
        // Determine the class for the order box
       $orderBoxClass = 'order-box';
switch ($order['order_status']) {
    case 'processing':
        $orderBoxClass .= ' processing';
        break;
    case 'handover':
        $orderBoxClass .= ' handover';
        break;
    case 'picked_up':
        $orderBoxClass .= ' picked_up';
        break;
    default:
        // Handle other status values if necessary
        break;
}
        // Define restaurant name based on restaurant ID
        $restaurantName = '';
        switch ($order['restaurant_id']) {
            case 2:
                $restaurantName = 'SaltNPepper';
                break;
            case 3:
                $restaurantName = 'Garlic Routes';
                break;
            case 4:
                $restaurantName = 'Chickow';
                break;
            case 5:
                $restaurantName = 'Happy Sip';
                break;
            default:
                $restaurantName = 'Unknown Restaurant';
                break;
        }
        // Fetch driver's name if available
        $driverName = '';
        if ($order['delivery_man_id']) {
            $query = $db->prepare("SELECT f_name, l_name FROM delivery_men WHERE id = :driverId");
            $query->bindParam(':driverId', $order['delivery_man_id']);
            $query->execute();
            $driver = $query->fetch(PDO::FETCH_ASSOC);
            if ($driver) {
                $driverName = $driver['f_name'] . ' ' . $driver['l_name'];
            }
        }
        // Check if a delivery man is assigned
        $driverAssigned = !empty($driverName);

        // Fetch delivery instruction and unavailable item note
        $deliveryInstruction = '';
        $unavailableItemNote = '';
        $orderNote = '';
        $query = $db->prepare("SELECT delivery_instruction, unavailable_item_note, order_note FROM orders WHERE id = :orderId");
        $query->bindParam(':orderId', $order['id']);
        $query->execute();
        $orderDetails = $query->fetch(PDO::FETCH_ASSOC);
        if ($orderDetails) {
            $deliveryInstruction = $orderDetails['delivery_instruction'];
            $unavailableItemNote = $orderDetails['unavailable_item_note'];
            $orderNote = $orderDetails['order_note'];
        }
        
        // Fetch order details from order_details table based on order ID
$query = $db->prepare("SELECT food_details, variation FROM order_details WHERE order_id = :orderId");
foreach ($nonTakeAwayOrders as &$order) {
    $query->bindParam(':orderId', $order['id']);
    $query->execute();
    $orderDetails = $query->fetchAll(PDO::FETCH_ASSOC);
    // Extracting name from food details
    $order['food_names'] = array_map(function($detail) {
        $foodDetail = json_decode($detail['food_details'], true);
        return $foodDetail['name'] ?? '';
    }, $orderDetails);
    // Extracting variations
    $order['variations'] = array_map(function($detail) {
        $variationDetail = json_decode($detail['variation'], true);
        return $variationDetail;
    }, $orderDetails);
}
    ?>
    <div class="<?php echo $orderBoxClass; ?>" onclick="handleNonTakeAwayOrderClick(<?php echo $order['id'] . ", '" . $order['order_status'] . "', " . ($driverAssigned ? 'true' : 'false') . ""; ?>)">
       <div class="order-header"><img src="cocoeats.png" alt="CocoEats Logo"></div>
        <div class="restaurant-name"><?php echo $restaurantName; ?></div>
        <strong>Order #<?php echo $order['id']; ?></strong><br>
        Status: <?php echo $order['order_status']; ?><br>
        <div class="time">Time: <?php echo $formattedDateTime; ?></div>
        <?php if (!empty($deliveryInstruction)) : ?>
            <div class="delivery-instruction">Delivery Instruction: <?php echo $deliveryInstruction; ?></div>
        <?php endif; ?>
        <?php if (!empty($unavailableItemNote)) : ?>
            <div class="unavailable-item-note">If item not available: <?php echo $unavailableItemNote; ?></div>
        <?php endif; ?>
        <?php if (!empty($orderNote)) : ?>
            <div class="order-note">Order Note: <?php echo $orderNote; ?></div>
        <?php endif; ?>
        <div class="status <?php echo $paymentStatusClass; ?>"><?php echo $order['payment_status']; ?></div>
        <?php if ($driverName) : ?>
            <div class="driver-box">
                <div class="driver-name"><?php echo $driverName; ?></div>
            </div>
        <?php endif; ?>
          <?php if (!empty($order['food_names'])) : ?>
            <?php foreach ($order['food_names'] as $index => $foodName) : ?>
                <div class="item-box" onclick="handleItemClick()">
                    <div class="item-details"><?php echo strtoupper($foodName); ?></div>
                    <?php if (!empty($order['variations'][$index])) : ?>
                        <?php foreach ($order['variations'][$index] as $variation) : ?>
                            <?php foreach ($variation['values'] as $value) : ?>
                                <div class="variation">
                                    <?php echo $variation['name'] . ": " . $value['label']; ?>
                                </div>
                            <?php endforeach; ?>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
<?php endforeach; ?>
<!-- Display take_away orders -->
<?php foreach ($takeAwayOrders as $order) : ?>
    <?php
        // Convert created_at to DateTime object
        $createdAt = new DateTime($order['created_at']);
        // Format date and time
        $formattedDateTime = $createdAt->format('Y-m-d H:i:s');
        // Determine the class for the payment status box
        $paymentStatusClass = ($order['payment_status'] === 'paid') ? 'paid' : 'unpaid';
        // Determine the class for the order box
        $orderBoxClass = 'order-box take-away';
        if ($order['order_status'] === 'processing') {
            $orderBoxClass .= ' processing';
        }
        // Define restaurant name based on restaurant ID
        $restaurantName = '';
        switch ($order['restaurant_id']) {
            case 2:
                $restaurantName = 'SaltNPepper';
                break;
            case 3:
                $restaurantName = 'Garlic Routes';
                break;
            case 4:
                $restaurantName = 'Chickow';
                break;
            case 5:
                $restaurantName = 'Happy Sip';
                break;
            default:
                $restaurantName = 'Unknown Restaurant';
                break;
        }

        // Fetch delivery instruction and unavailable item note
        $deliveryInstruction = '';
        $unavailableItemNote = '';
        $orderNote = '';
        $query = $db->prepare("SELECT delivery_instruction, unavailable_item_note, order_note FROM orders WHERE id = :orderId");
        $query->bindParam(':orderId', $order['id']);
        $query->execute();
        $orderDetails = $query->fetch(PDO::FETCH_ASSOC);
        if ($orderDetails) {
            $deliveryInstruction = $orderDetails['delivery_instruction'];
            $unavailableItemNote = $orderDetails['unavailable_item_note'];
            $orderNote = $orderDetails['order_note'];
        }
        
   $query = $db->prepare("SELECT food_details, variation FROM order_details WHERE order_id = :orderId");     
        foreach ($takeAwayOrders as &$order) {
    $query->bindParam(':orderId', $order['id']);
    $query->execute();
    $orderDetails = $query->fetchAll(PDO::FETCH_ASSOC);
    // Extracting name from food details
    $order['food_names'] = array_map(function($detail) {
        $foodDetail = json_decode($detail['food_details'], true);
        return $foodDetail['name'] ?? '';
    }, $orderDetails);
    // Extracting variations
    $order['variations'] = array_map(function($detail) {
        $variationDetail = json_decode($detail['variation'], true);
        return $variationDetail;
    }, $orderDetails);
}


    ?>
    <div class="<?php echo $orderBoxClass; ?>" onclick="handleTakeAwayOrderDoubleClick(<?php echo $order['id'] . ", '" . $order['order_status'] . "'"; ?>)">
         <div class="order-header"><img src="cocoeats.png" alt="CocoEats Logo"></div>
        <div class="order-content">
            <div class="restaurant-name"><?php echo $restaurantName; ?></div>
            <strong>Order #<?php echo $order['id']; ?></strong><br>
            Status: <?php echo $order['order_status']; ?><br>
            <div class="time">Time: <?php echo $formattedDateTime; ?></div>
            <?php if (!empty($deliveryInstruction)) : ?>
                <div class="delivery-instruction">Delivery Instruction: <?php echo $deliveryInstruction; ?></div>
            <?php endif; ?>
            <?php if (!empty($unavailableItemNote)) : ?>
                <div class="unavailable-item-note">If item not available: <?php echo $unavailableItemNote; ?></div>
            <?php endif; ?>
            <?php if (!empty($orderNote)) : ?>
                <div class="order-note">Order Note: <?php echo $orderNote; ?></div>
            <?php endif; ?>
            <div class="status <?php echo $paymentStatusClass; ?>"><?php echo $order['payment_status']; ?></div>
        </div>
 <?php if (!empty($order['food_names'])) : ?>
            <?php foreach ($order['food_names'] as $index => $foodName) : ?>
                <div class="item-box" onclick="handleItemClick()">
                    <div class="item-details"><?php echo strtoupper($foodName); ?></div>
                    <?php if (!empty($order['variations'][$index])) : ?>
                        <?php foreach ($order['variations'][$index] as $variation) : ?>
                            <?php foreach ($variation['values'] as $value) : ?>
                                <div class="variation">
                                    <?php echo $variation['name'] . ": " . $value['label']; ?>
                                </div>
                            <?php endforeach; ?>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
<?php endforeach; ?>

<script>
    // Variable to track last click time
    var lastClickTime = 0;

    // Function to handle click on non take_away orders
    function handleNonTakeAwayOrderClick(orderId, orderStatus, driverAssigned) {
        var currentTime = new Date().getTime();
        // Check if it's a double click (within 500 milliseconds)
        if (currentTime - lastClickTime < 500) {
            // Double click detected, update order status to 'handover' if conditions are met
            if (orderStatus === 'processing' && driverAssigned) {
                updateOrderStatus(orderId, 'handover');
            }
        } else {
            // Single click detected
            if (orderStatus !== 'processing') {
                // Redirect to select driver page
                window.location.href = 'select_driver.php?orderId=' + orderId;
            } else if (!driverAssigned) {
                // If driver is not assigned, also redirect to select driver page
                window.location.href = 'select_driver.php?orderId=' + orderId;
            }
        }
        lastClickTime = currentTime;
    }

    // Function to handle double click on take_away orders
    function handleTakeAwayOrderDoubleClick(orderId, orderStatus) {
        var currentTime = new Date().getTime();
        // Check if it's a double click (within 500 milliseconds)
        if (currentTime - lastClickTime < 500) {
            // Double click detected
            if (orderStatus === 'pending' || orderStatus === 'confirmed') {
                // If order is pending or confirmed, update status to processing
                updateOrderStatus(orderId, 'processing');
            } else if (orderStatus === 'processing') {
                // If order is already processing, update status to delivered
                updateOrderStatus(orderId, 'delivered');
            }
        }
        lastClickTime = currentTime;
    }

    // Function to update order status
    function updateOrderStatus(orderId, status) {
        // Send AJAX request to update order status
        var xhr = new XMLHttpRequest();
        xhr.open("POST", "update_order_status.php", true);
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.onreadystatechange = function() {
            if (xhr.readyState === 4 && xhr.status === 200) {
                // Reload the page to reflect the changes
                location.reload();
            }
        };
        xhr.send("orderId=" + orderId + "&status=" + status);
    }

    // Auto-refresh every 20 seconds
    setTimeout(function () {
        location.reload();
    }, 20000);
</script>
</body>
</html>
