<?php
session_start();

// Check if the user is not logged in, redirect to login page
if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
    header('Location: login.php');
    exit;
}

// Database connection details
$dbHost = 'localhost';
$dbName = 'cocoeatz_app';
$dbUser = 'cocoeatz_test';
$dbPassword = 'Msnt@786';

try {
    // Connect to Database
    $db = new PDO("mysql:host=$dbHost;dbname=$dbName", $dbUser, $dbPassword);
    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}



// Fetch take_away orders where restaurant_id is 3, 4, or 5, order_status is not 'delivered' or 'canceled', created_at is today, and payment_method is not 'digital_payment'
$query = $db->prepare("SELECT id, order_status, payment_status, created_at, restaurant_id, delivery_man_id FROM orders WHERE restaurant_id IN (3, 4, 5) AND order_status NOT IN ('delivered', 'canceled') AND DATE(created_at) = :today AND payment_method != 'digital_payment' AND order_type = 'take_away' ORDER BY created_at DESC");
$query->bindParam(':today', $today);
$query->execute();
$takeAwayOrders = $query->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Order Management System</title>
    <style>
        body {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-content: flex-start;
            padding: 10px;
            font-family: Arial, sans-serif;
        }

        .order-box {
            padding: 20px;
            background-color: #f0f0f0;
            border-radius: 5px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
            flex-basis: calc(5/7 * 25% - 20px);
            position: relative;
            overflow: hidden;
        }

        .order-box.processing {
            background-color: #9400d3; /* Dark blue background for processing orders */
        }

        .order-box.take-away {
            background-color: #ffdab9; /* Light pink background for take_away orders */
        }

        .order-box.take-away.processing {
            background-color: #9400d3; /* Dark blue background for processing take_away orders */
        }

        .order-box:not(.processing):not(.take-away):hover {
            background-color: #e6e6e6;
            cursor: pointer;
        }

        .order-box.take-away:hover {
            background-color: #ffc0cb; /* Light pink background for take_away orders on hover */
        }

        .order-box.take-away.processing:hover {
            background-color: #8a2be2; /* Dark blue background for processing take_away orders on hover */
        }

        .order-box .restaurant-name {
            font-weight: bold;
            margin-top: 10px;
        }

        .order-box strong {
            font-size: 18px;
        }

        .order-box .time {
            font-size: 14px;
            color: #666;
        }

        .order-box .status {
            position: absolute;
            top: 20px;
            right: 10px;
            padding: 10px;
            border-radius: 5px;
            font-size: 14px;
            color: white;
        }

        .order-box .status.paid {
            background-color: green;
        }

        .order-box .status.unpaid {
            background-color: red;
        }

        .order-box .driver-box .driver-name {
            display: inline-block;
            padding: 5px 10px;
            background-color: orange;
            border-radius: 5px;
            color: white;
            font-weight: bold;
        }

        .order-box .delivery-instruction,
        .order-box .unavailable-item-note {
            margin-top: 10px;
            font-size: 14px;
        }

        .order-box .delivery-instruction p,
        .order-box .unavailable-item-note p {
            font-style: italic;
            margin-top: 5px;
        }
    </style>
</head>
<body>

<!-- Display take_away orders -->
<?php foreach ($takeAwayOrders as $order) : ?>
    <?php
        // Convert created_at to DateTime object
        $createdAt = new DateTime($order['created_at']);
        // Format date and time
        $formattedDateTime = $createdAt->format('Y-m-d H:i:s');
        // Determine the class for the payment status box
        $paymentStatusClass = ($order['payment_status'] === 'paid') ? 'paid' : 'unpaid';
        // Determine the class for the order box
        $orderBoxClass = 'order-box take-away';
        if ($order['order_status'] === 'processing') {
            $orderBoxClass .= ' processing';
        }
        // Define restaurant name based on restaurant ID
        $restaurantName = '';
        switch ($order['restaurant_id']) {
            case 2:
                $restaurantName = 'SaltNPepper';
                break;
            case 3:
                $restaurantName = 'Garlic Routes';
                break;
            case 4:
                $restaurantName = 'Chickow';
                break;
            case 5:
                $restaurantName = 'Happy Sip';
                break;
            default:
                $restaurantName = 'Unknown Restaurant';
                break;
        }
        // Fetch driver's name if available
        $driverName = '';
        if ($order['delivery_man_id']) {
            $query = $db->prepare("SELECT f_name, l_name FROM delivery_men WHERE id = :driverId");
            $query->bindParam(':driverId', $order['delivery_man_id']);
            $query->execute();
            $driver = $query->fetch(PDO::FETCH_ASSOC);
            if ($driver) {
                $driverName = $driver['f_name'] . ' ' . $driver['l_name'];
            }
        }
        // Check if a delivery man is assigned
        $driverAssigned = !empty($driverName);

        // Fetch delivery instruction and unavailable item note
        $deliveryInstruction = '';
        $unavailableItemNote = '';
        $query = $db->prepare("SELECT delivery_instruction, unavailable_item_note FROM orders WHERE id = :orderId");
        $query->bindParam(':orderId', $order['id']);
        $query->execute();
        $orderDetails = $query->fetch(PDO::FETCH_ASSOC);
        if ($orderDetails) {
            $deliveryInstruction = $orderDetails['delivery_instruction'];
            $unavailableItemNote = $orderDetails['unavailable_item_note'];
        }
    ?>
    <div class="<?php echo $orderBoxClass; ?>" onclick="handleTakeAwayOrderClick(<?php echo $order['id'] . ", '" . $order['order_status'] . "', " . ($driverAssigned ? 'true' : 'false') . ""; ?>)">
        <div class="restaurant-name"><?php echo $restaurantName; ?></div>
        <strong>Order #<?php echo $order['id']; ?></strong><br>
        Status: <?php echo $order['order_status']; ?><br>
        <div class="time">Time: <?php echo $formattedDateTime; ?></div>
        <?php if (!empty($deliveryInstruction)) : ?>
            <div class="delivery-instruction">Delivery Instruction: <?php echo $deliveryInstruction; ?></div>
        <?php endif; ?>
        <?php if (!empty($unavailableItemNote)) : ?>
            <div class="unavailable-item-note">If item not available: <?php echo $unavailableItemNote; ?></div>
        <?php endif; ?>
        <div class="status <?php echo $paymentStatusClass; ?>"><?php echo $order['payment_status']; ?></div>
        <?php if ($driverName) : ?>
            <div class="driver-box">
                <div class="driver-name"><?php echo $driverName; ?></div>
            </div>
        <?php endif; ?>
    </div>
<?php endforeach; ?>


<script>
    // Variable to track last click time
    var lastClickTime = 0;



    // Function to handle click on take_away orders
    function handleTakeAwayOrderClick(orderId, orderStatus, driverAssigned) {
        var currentTime = new Date().getTime();
        // Check if it's a double click (within 500 milliseconds)
        if (currentTime - lastClickTime < 500) {
            // Double click detected, update order status to 'processing' if conditions are met
            if (orderStatus === 'processing' && driverAssigned) {
                updateOrderStatus(orderId, 'processing');
            }
        } else {
            // Single click detected
            if (orderStatus !== 'processing') {
                // Redirect to select driver page
                window.location.href = 'select_driver.php?orderId=' + orderId;
            } else if (!driverAssigned) {
                // If driver is not assigned, also redirect to select driver page
                window.location.href = 'select_driver.php?orderId=' + orderId;
            }
        }
        lastClickTime = currentTime;
    }

    // Function to update order status
    function updateOrderStatus(orderId, status) {
        // Send AJAX request to update order status
        var xhr = new XMLHttpRequest();
        xhr.open("POST", "update_order_status.php", true);
        xhr.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        xhr.onreadystatechange = function() {
            if (xhr.readyState === 4 && xhr.status === 200) {
                // Reload the page to reflect the changes
                location.reload();
            }
        };
        xhr.send("orderId=" + orderId + "&status=" + status);
    }

    // Auto-refresh every 20 seconds
    setTimeout(function () {
        location.reload();
    }, 20000);
</script>
</body>
</html>
